==> vtk6-6.3.0-9-aarch64.pkg.tar.xz: vtk/vtkImageTracerWidget.java <==
// java wrapper for vtkImageTracerWidget object
//

package vtk;
import vtk.*;

public class vtkImageTracerWidget extends vtk3DWidget
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetEnabled_2(int id0);
  public void SetEnabled(int id0)
    { SetEnabled_2(id0); }

  private native void PlaceWidget_3(double id0[]);
  public void PlaceWidget(double id0[])
    { PlaceWidget_3(id0); }

  private native void PlaceWidget_4();
  public void PlaceWidget()
    { PlaceWidget_4(); }

  private native void PlaceWidget_5(double id0,double id1,double id2,double id3,double id4,double id5);
  public void PlaceWidget(double id0,double id1,double id2,double id3,double id4,double id5)
    { PlaceWidget_5(id0,id1,id2,id3,id4,id5); }

  private native void SetHandleProperty_6(vtkProperty id0);
  public void SetHandleProperty(vtkProperty id0)
    { SetHandleProperty_6(id0); }

  private native long GetHandleProperty_7();
  public vtkProperty GetHandleProperty() {
    long temp = GetHandleProperty_7();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetSelectedHandleProperty_8(vtkProperty id0);
  public void SetSelectedHandleProperty(vtkProperty id0)
    { SetSelectedHandleProperty_8(id0); }

  private native long GetSelectedHandleProperty_9();
  public vtkProperty GetSelectedHandleProperty() {
    long temp = GetSelectedHandleProperty_9();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetLineProperty_10(vtkProperty id0);
  public void SetLineProperty(vtkProperty id0)
    { SetLineProperty_10(id0); }

  private native long GetLineProperty_11();
  public vtkProperty GetLineProperty() {
    long temp = GetLineProperty_11();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetSelectedLineProperty_12(vtkProperty id0);
  public void SetSelectedLineProperty(vtkProperty id0)
    { SetSelectedLineProperty_12(id0); }

  private native long GetSelectedLineProperty_13();
  public vtkProperty GetSelectedLineProperty() {
    long temp = GetSelectedLineProperty_13();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetViewProp_14(vtkProp id0);
  public void SetViewProp(vtkProp id0)
    { SetViewProp_14(id0); }

  private native void SetProjectToPlane_15(int id0);
  public void SetProjectToPlane(int id0)
    { SetProjectToPlane_15(id0); }

  private native int GetProjectToPlane_16();
  public int GetProjectToPlane()
    { return GetProjectToPlane_16(); }

  private native void ProjectToPlaneOn_17();
  public void ProjectToPlaneOn()
    { ProjectToPlaneOn_17(); }

  private native void ProjectToPlaneOff_18();
  public void ProjectToPlaneOff()
    { ProjectToPlaneOff_18(); }

  private native void SetProjectionNormal_19(int id0);
  public void SetProjectionNormal(int id0)
    { SetProjectionNormal_19(id0); }

  private native int GetProjectionNormalMinValue_20();
  public int GetProjectionNormalMinValue()
    { return GetProjectionNormalMinValue_20(); }

  private native int GetProjectionNormalMaxValue_21();
  public int GetProjectionNormalMaxValue()
    { return GetProjectionNormalMaxValue_21(); }

  private native int GetProjectionNormal_22();
  public int GetProjectionNormal()
    { return GetProjectionNormal_22(); }

  private native void SetProjectionNormalToXAxes_23();
  public void SetProjectionNormalToXAxes()
    { SetProjectionNormalToXAxes_23(); }

  private native void SetProjectionNormalToYAxes_24();
  public void SetProjectionNormalToYAxes()
    { SetProjectionNormalToYAxes_24(); }

  private native void SetProjectionNormalToZAxes_25();
  public void SetProjectionNormalToZAxes()
    { SetProjectionNormalToZAxes_25(); }

  private native void SetProjectionPosition_26(double id0);
  public void SetProjectionPosition(double id0)
    { SetProjectionPosition_26(id0); }

  private native double GetProjectionPosition_27();
  public double GetProjectionPosition()
    { return GetProjectionPosition_27(); }

  private native void SetSnapToImage_28(int id0);
  public void SetSnapToImage(int id0)
    { SetSnapToImage_28(id0); }

  private native int GetSnapToImage_29();
  public int GetSnapToImage()
    { return GetSnapToImage_29(); }

  private native void SnapToImageOn_30();
  public void SnapToImageOn()
    { SnapToImageOn_30(); }

  private native void SnapToImageOff_31();
  public void SnapToImageOff()
    { SnapToImageOff_31(); }

  private native void SetAutoClose_32(int id0);
  public void SetAutoClose(int id0)
    { SetAutoClose_32(id0); }

  private native int GetAutoClose_33();
  public int GetAutoClose()
    { return GetAutoClose_33(); }

  private native void AutoCloseOn_34();
  public void AutoCloseOn()
    { AutoCloseOn_34(); }

  private native void AutoCloseOff_35();
  public void AutoCloseOff()
    { AutoCloseOff_35(); }

  private native void SetCaptureRadius_36(double id0);
  public void SetCaptureRadius(double id0)
    { SetCaptureRadius_36(id0); }

  private native double GetCaptureRadius_37();
  public double GetCaptureRadius()
    { return GetCaptureRadius_37(); }

  private native void GetPath_38(vtkPolyData id0);
  public void GetPath(vtkPolyData id0)
    { GetPath_38(id0); }

  private native long GetGlyphSource_39();
  public vtkGlyphSource2D GetGlyphSource() {
    long temp = GetGlyphSource_39();

    if (temp == 0) return null;
    return (vtkGlyphSource2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetImageSnapType_40(int id0);
  public void SetImageSnapType(int id0)
    { SetImageSnapType_40(id0); }

  private native int GetImageSnapTypeMinValue_41();
  public int GetImageSnapTypeMinValue()
    { return GetImageSnapTypeMinValue_41(); }

  private native int GetImageSnapTypeMaxValue_42();
  public int GetImageSnapTypeMaxValue()
    { return GetImageSnapTypeMaxValue_42(); }

  private native int GetImageSnapType_43();
  public int GetImageSnapType()
    { return GetImageSnapType_43(); }

  private native void SetHandlePosition_44(int id0,double id1[]);
  public void SetHandlePosition(int id0,double id1[])
    { SetHandlePosition_44(id0,id1); }

  private native void SetHandlePosition_45(int id0,double id1,double id2,double id3);
  public void SetHandlePosition(int id0,double id1,double id2,double id3)
    { SetHandlePosition_45(id0,id1,id2,id3); }

  private native void GetHandlePosition_46(int id0,double id1[]);
  public void GetHandlePosition(int id0,double id1[])
    { GetHandlePosition_46(id0,id1); }

  private native double[] GetHandlePosition_47(int id0);
  public double[] GetHandlePosition(int id0)
    { return GetHandlePosition_47(id0); }

  private native int GetNumberOfHandles_48();
  public int GetNumberOfHandles()
    { return GetNumberOfHandles_48(); }

  private native void SetInteraction_49(int id0);
  public void SetInteraction(int id0)
    { SetInteraction_49(id0); }

  private native int GetInteraction_50();
  public int GetInteraction()
    { return GetInteraction_50(); }

  private native void InteractionOn_51();
  public void InteractionOn()
    { InteractionOn_51(); }

  private native void InteractionOff_52();
  public void InteractionOff()
    { InteractionOff_52(); }

  private native void InitializeHandles_53(vtkPoints id0);
  public void InitializeHandles(vtkPoints id0)
    { InitializeHandles_53(id0); }

  private native int IsClosed_54();
  public int IsClosed()
    { return IsClosed_54(); }

  private native void SetHandleLeftMouseButton_55(int id0);
  public void SetHandleLeftMouseButton(int id0)
    { SetHandleLeftMouseButton_55(id0); }

  private native int GetHandleLeftMouseButton_56();
  public int GetHandleLeftMouseButton()
    { return GetHandleLeftMouseButton_56(); }

  private native void HandleLeftMouseButtonOn_57();
  public void HandleLeftMouseButtonOn()
    { HandleLeftMouseButtonOn_57(); }

  private native void HandleLeftMouseButtonOff_58();
  public void HandleLeftMouseButtonOff()
    { HandleLeftMouseButtonOff_58(); }

  private native void SetHandleMiddleMouseButton_59(int id0);
  public void SetHandleMiddleMouseButton(int id0)
    { SetHandleMiddleMouseButton_59(id0); }

  private native int GetHandleMiddleMouseButton_60();
  public int GetHandleMiddleMouseButton()
    { return GetHandleMiddleMouseButton_60(); }

  private native void HandleMiddleMouseButtonOn_61();
  public void HandleMiddleMouseButtonOn()
    { HandleMiddleMouseButtonOn_61(); }

  private native void HandleMiddleMouseButtonOff_62();
  public void HandleMiddleMouseButtonOff()
    { HandleMiddleMouseButtonOff_62(); }

  private native void SetHandleRightMouseButton_63(int id0);
  public void SetHandleRightMouseButton(int id0)
    { SetHandleRightMouseButton_63(id0); }

  private native int GetHandleRightMouseButton_64();
  public int GetHandleRightMouseButton()
    { return GetHandleRightMouseButton_64(); }

  private native void HandleRightMouseButtonOn_65();
  public void HandleRightMouseButtonOn()
    { HandleRightMouseButtonOn_65(); }

  private native void HandleRightMouseButtonOff_66();
  public void HandleRightMouseButtonOff()
    { HandleRightMouseButtonOff_66(); }

  public vtkImageTracerWidget() { super(); }

  public vtkImageTracerWidget(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-aarch64.pkg.tar.xz: vtk/vtkImageTracerWidget.java <==
// java wrapper for vtkImageTracerWidget object
//

package vtk;
import vtk.*;

public class vtkImageTracerWidget extends vtk3DWidget
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetEnabled_2(int id0);
  public void SetEnabled(int id0)
    { SetEnabled_2(id0); }

  private native void PlaceWidget_3(double id0[]);
  public void PlaceWidget(double id0[])
    { PlaceWidget_3(id0); }

  private native void PlaceWidget_4();
  public void PlaceWidget()
    { PlaceWidget_4(); }

  private native void PlaceWidget_5(double id0,double id1,double id2,double id3,double id4,double id5);
  public void PlaceWidget(double id0,double id1,double id2,double id3,double id4,double id5)
    { PlaceWidget_5(id0,id1,id2,id3,id4,id5); }

  private native void SetHandleProperty_6(vtkProperty id0);
  public void SetHandleProperty(vtkProperty id0)
    { SetHandleProperty_6(id0); }

  private native long GetHandleProperty_7();
  public vtkProperty GetHandleProperty() {
    long temp = GetHandleProperty_7();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSelectedHandleProperty_8(vtkProperty id0);
  public void SetSelectedHandleProperty(vtkProperty id0)
    { SetSelectedHandleProperty_8(id0); }

  private native long GetSelectedHandleProperty_9();
  public vtkProperty GetSelectedHandleProperty() {
    long temp = GetSelectedHandleProperty_9();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLineProperty_10(vtkProperty id0);
  public void SetLineProperty(vtkProperty id0)
    { SetLineProperty_10(id0); }

  private native long GetLineProperty_11();
  public vtkProperty GetLineProperty() {
    long temp = GetLineProperty_11();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSelectedLineProperty_12(vtkProperty id0);
  public void SetSelectedLineProperty(vtkProperty id0)
    { SetSelectedLineProperty_12(id0); }

  private native long GetSelectedLineProperty_13();
  public vtkProperty GetSelectedLineProperty() {
    long temp = GetSelectedLineProperty_13();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetViewProp_14(vtkProp id0);
  public void SetViewProp(vtkProp id0)
    { SetViewProp_14(id0); }

  private native void SetProjectToPlane_15(int id0);
  public void SetProjectToPlane(int id0)
    { SetProjectToPlane_15(id0); }

  private native int GetProjectToPlane_16();
  public int GetProjectToPlane()
    { return GetProjectToPlane_16(); }

  private native void ProjectToPlaneOn_17();
  public void ProjectToPlaneOn()
    { ProjectToPlaneOn_17(); }

  private native void ProjectToPlaneOff_18();
  public void ProjectToPlaneOff()
    { ProjectToPlaneOff_18(); }

  private native void SetProjectionNormal_19(int id0);
  public void SetProjectionNormal(int id0)
    { SetProjectionNormal_19(id0); }

  private native int GetProjectionNormalMinValue_20();
  public int GetProjectionNormalMinValue()
    { return GetProjectionNormalMinValue_20(); }

  private native int GetProjectionNormalMaxValue_21();
  public int GetProjectionNormalMaxValue()
    { return GetProjectionNormalMaxValue_21(); }

  private native int GetProjectionNormal_22();
  public int GetProjectionNormal()
    { return GetProjectionNormal_22(); }

  private native void SetProjectionNormalToXAxes_23();
  public void SetProjectionNormalToXAxes()
    { SetProjectionNormalToXAxes_23(); }

  private native void SetProjectionNormalToYAxes_24();
  public void SetProjectionNormalToYAxes()
    { SetProjectionNormalToYAxes_24(); }

  private native void SetProjectionNormalToZAxes_25();
  public void SetProjectionNormalToZAxes()
    { SetProjectionNormalToZAxes_25(); }

  private native void SetProjectionPosition_26(double id0);
  public void SetProjectionPosition(double id0)
    { SetProjectionPosition_26(id0); }

  private native double GetProjectionPosition_27();
  public double GetProjectionPosition()
    { return GetProjectionPosition_27(); }

  private native void SetSnapToImage_28(int id0);
  public void SetSnapToImage(int id0)
    { SetSnapToImage_28(id0); }

  private native int GetSnapToImage_29();
  public int GetSnapToImage()
    { return GetSnapToImage_29(); }

  private native void SnapToImageOn_30();
  public void SnapToImageOn()
    { SnapToImageOn_30(); }

  private native void SnapToImageOff_31();
  public void SnapToImageOff()
    { SnapToImageOff_31(); }

  private native void SetAutoClose_32(int id0);
  public void SetAutoClose(int id0)
    { SetAutoClose_32(id0); }

  private native int GetAutoClose_33();
  public int GetAutoClose()
    { return GetAutoClose_33(); }

  private native void AutoCloseOn_34();
  public void AutoCloseOn()
    { AutoCloseOn_34(); }

  private native void AutoCloseOff_35();
  public void AutoCloseOff()
    { AutoCloseOff_35(); }

  private native void SetCaptureRadius_36(double id0);
  public void SetCaptureRadius(double id0)
    { SetCaptureRadius_36(id0); }

  private native double GetCaptureRadius_37();
  public double GetCaptureRadius()
    { return GetCaptureRadius_37(); }

  private native void GetPath_38(vtkPolyData id0);
  public void GetPath(vtkPolyData id0)
    { GetPath_38(id0); }

  private native long GetGlyphSource_39();
  public vtkGlyphSource2D GetGlyphSource() {
    long temp = GetGlyphSource_39();

    if (temp == 0) return null;
    return (vtkGlyphSource2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetImageSnapType_40(int id0);
  public void SetImageSnapType(int id0)
    { SetImageSnapType_40(id0); }

  private native int GetImageSnapTypeMinValue_41();
  public int GetImageSnapTypeMinValue()
    { return GetImageSnapTypeMinValue_41(); }

  private native int GetImageSnapTypeMaxValue_42();
  public int GetImageSnapTypeMaxValue()
    { return GetImageSnapTypeMaxValue_42(); }

  private native int GetImageSnapType_43();
  public int GetImageSnapType()
    { return GetImageSnapType_43(); }

  private native void SetHandlePosition_44(int id0,double id1[]);
  public void SetHandlePosition(int id0,double id1[])
    { SetHandlePosition_44(id0,id1); }

  private native void SetHandlePosition_45(int id0,double id1,double id2,double id3);
  public void SetHandlePosition(int id0,double id1,double id2,double id3)
    { SetHandlePosition_45(id0,id1,id2,id3); }

  private native void GetHandlePosition_46(int id0,double id1[]);
  public void GetHandlePosition(int id0,double id1[])
    { GetHandlePosition_46(id0,id1); }

  private native double[] GetHandlePosition_47(int id0);
  public double[] GetHandlePosition(int id0)
    { return GetHandlePosition_47(id0); }

  private native int GetNumberOfHandles_48();
  public int GetNumberOfHandles()
    { return GetNumberOfHandles_48(); }

  private native void SetInteraction_49(int id0);
  public void SetInteraction(int id0)
    { SetInteraction_49(id0); }

  private native int GetInteraction_50();
  public int GetInteraction()
    { return GetInteraction_50(); }

  private native void InteractionOn_51();
  public void InteractionOn()
    { InteractionOn_51(); }

  private native void InteractionOff_52();
  public void InteractionOff()
    { InteractionOff_52(); }

  private native void InitializeHandles_53(vtkPoints id0);
  public void InitializeHandles(vtkPoints id0)
    { InitializeHandles_53(id0); }

  private native int IsClosed_54();
  public int IsClosed()
    { return IsClosed_54(); }

  private native void SetHandleLeftMouseButton_55(int id0);
  public void SetHandleLeftMouseButton(int id0)
    { SetHandleLeftMouseButton_55(id0); }

  private native int GetHandleLeftMouseButton_56();
  public int GetHandleLeftMouseButton()
    { return GetHandleLeftMouseButton_56(); }

  private native void HandleLeftMouseButtonOn_57();
  public void HandleLeftMouseButtonOn()
    { HandleLeftMouseButtonOn_57(); }

  private native void HandleLeftMouseButtonOff_58();
  public void HandleLeftMouseButtonOff()
    { HandleLeftMouseButtonOff_58(); }

  private native void SetHandleMiddleMouseButton_59(int id0);
  public void SetHandleMiddleMouseButton(int id0)
    { SetHandleMiddleMouseButton_59(id0); }

  private native int GetHandleMiddleMouseButton_60();
  public int GetHandleMiddleMouseButton()
    { return GetHandleMiddleMouseButton_60(); }

  private native void HandleMiddleMouseButtonOn_61();
  public void HandleMiddleMouseButtonOn()
    { HandleMiddleMouseButtonOn_61(); }

  private native void HandleMiddleMouseButtonOff_62();
  public void HandleMiddleMouseButtonOff()
    { HandleMiddleMouseButtonOff_62(); }

  private native void SetHandleRightMouseButton_63(int id0);
  public void SetHandleRightMouseButton(int id0)
    { SetHandleRightMouseButton_63(id0); }

  private native int GetHandleRightMouseButton_64();
  public int GetHandleRightMouseButton()
    { return GetHandleRightMouseButton_64(); }

  private native void HandleRightMouseButtonOn_65();
  public void HandleRightMouseButtonOn()
    { HandleRightMouseButtonOn_65(); }

  private native void HandleRightMouseButtonOff_66();
  public void HandleRightMouseButtonOff()
    { HandleRightMouseButtonOff_66(); }

  public vtkImageTracerWidget() { super(); }

  public vtkImageTracerWidget(long id) { super(id); }
  public native long   VTKInit();

}
